@@ -28,7 +28,8 @@ class get_top_keyword:
         print('==========开始获取【%s】产品相关数据==========' %(self.app_name))
         while self.start_time <= self.end_time:
             get_app_keyword_data = get_app_keyword(self.appid)
-            get_app_keyword_data.start_time = self.start_time
+            get_app_keyword_data.run_time = self.start_time
+            get_app_keyword_data.keyword_hot_start = self.keyword_hot_start
             res = get_app_keyword_data.get_keywordDetail()
             if res['msg'] == '成功' and len(res['data']) > 0:
                 df_keyword = qimai_outside_tool(res['data']).json_to_df()
@@ -59,8 +60,7 @@ class get_top_keyword:
                 self.now_app_list.append(self.appid)
 
             self.start_time += self.one_day
-
-        return pd.DataFrame({
+        df = pd.DataFrame({
             'AppID': self.now_app_list,
             '日期': self.date_list,
             'T1数量': self.t1_all_list,
@@ -69,6 +69,7 @@ class get_top_keyword:
             'T5数量': self.t5_all_list,
             'T10数量': self.t10_all_list
         })
+        return df
 
 
 class get_multiple_top_keyword():
